==> haskell-entropy-0.4.1.6-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-entropy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 entropy
version:              0.4.1.6
visibility:           public
id:                   entropy-0.4.1.6-26HTmWCKtLlHik4pqnwJfR
key:                  entropy-0.4.1.6-26HTmWCKtLlHik4pqnwJfR
license:              BSD-3-Clause
copyright:            Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer:           Thomas DuBuisson <thomas.dubuisson@gmail.com>
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
homepage:             https://github.com/TomMD/entropy
synopsis:             A platform independent entropy source
description:
    A mostly platform independent method to obtain cryptographically strong entropy
    (RDRAND, urandom, CryptAPI, and patches welcome)
    Users looking for cryptographically strong (number-theoretically
    sound) PRNGs should see the '\''DRBG'\'' package too.

category:             Data, Cryptography
abi:                  9ce44780af01e701a82f157586871535
exposed:              True
exposed-modules:      System.Entropy
hidden-modules:       System.EntropyNix
import-dirs:          /usr/lib/ghc-8.8.3/site-local/entropy-0.4.1.6
library-dirs:         /usr/lib/ghc-8.8.3/site-local/entropy-0.4.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/entropy-0.4.1.6
hs-libraries:         HSentropy-0.4.1.6-26HTmWCKtLlHik4pqnwJfR
depends:              base-4.13.0.0 bytestring-0.10.10.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-entropy/html/entropy.haddock
haddock-html:         /usr/share/doc/haskell-entropy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-entropy-0.4.1.6-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-entropy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 entropy
version:              0.4.1.6
visibility:           public
id:                   entropy-0.4.1.6-FlQhn1x7lTc9FFhbQ0zOpu
key:                  entropy-0.4.1.6-FlQhn1x7lTc9FFhbQ0zOpu
license:              BSD-3-Clause
copyright:            Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer:           Thomas DuBuisson <thomas.dubuisson@gmail.com>
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
homepage:             https://github.com/TomMD/entropy
synopsis:             A platform independent entropy source
description:
    A mostly platform independent method to obtain cryptographically strong entropy
    (RDRAND, urandom, CryptAPI, and patches welcome)
    Users looking for cryptographically strong (number-theoretically
    sound) PRNGs should see the '\''DRBG'\'' package too.

category:             Data, Cryptography
abi:                  1dfb7361b4fd690517c3f8058653854f
exposed:              True
exposed-modules:      System.Entropy
hidden-modules:       System.EntropyNix
import-dirs:          /usr/lib/ghc-8.10.1/site-local/entropy-0.4.1.6
library-dirs:         /usr/lib/ghc-8.10.1/site-local/entropy-0.4.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/entropy-0.4.1.6
hs-libraries:         HSentropy-0.4.1.6-FlQhn1x7lTc9FFhbQ0zOpu
depends:              base-4.14.0.0 bytestring-0.10.10.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-entropy/html/entropy.haddock
haddock-html:         /usr/share/doc/haskell-entropy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
